@@ -5,13 +5,13 @@
         <location filename="mainwindow.ui" line="26"/>
         <location filename="ui_mainwindow.h" line="888"/>
         <source>User Manager</source>
-        <translation>Upravljanje uporabnikov</translation>
+        <translation>Upravljalnik uporabnikov</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="62"/>
         <location filename="ui_mainwindow.h" line="945"/>
         <source>Administration</source>
-        <translation>administracija</translation>
+        <translation>Administracija</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="65"/>
@@ -137,13 +137,13 @@
         <location filename="mainwindow.ui" line="364"/>
         <location filename="ui_mainwindow.h" line="927"/>
         <source>Also delete the user&apos;s home directory</source>
-        <translation>Izbriši tudi domačo mapo uporabnika</translation>
+        <translation>Izbriši tudi domači direktorij uporabnika</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="367"/>
         <location filename="ui_mainwindow.h" line="929"/>
         <source>Delete user home directory</source>
-        <translation>Izbriši domačo mapo uporabnika</translation>
+        <translation>Izbriši domači direktorij uporabnika</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="380"/>
@@ -656,7 +656,7 @@ Prosimo, izberite drugo ime pred nadaljevanjem.</translation>
     <message>
         <location filename="mainwindow.cpp" line="336"/>
         <source>Sorry, this name is in use. Please enter a different name.</source>
-        <translation>Oprostite, to ime je že v rabi. Izberite drugo ime.</translation>
+        <translation>Oprostite, to ime se že uporablja. Izberite drugo ime.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="340"/>
@@ -762,7 +762,7 @@ Izberite drugo ime.</translation>
     <message>
         <location filename="mainwindow.cpp" line="490"/>
         <source>The selected user name is currently in use.</source>
-        <translation>Izbrano uporabniško ime je trenutno v rabi.</translation>
+        <translation>Izbrano uporabniško ime se že uporablja.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="491"/>
@@ -895,7 +895,7 @@ Izberite drugo ime.</translation>
     <message>
         <location filename="main.cpp" line="46"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
-        <translation>Prijevljeni ste kot korenski uporabnik. Izpišite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
+        <translation>Prijavljeni ste kot korenski (root) uporabnik. Izpišite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
